summaryrefslogtreecommitdiffstats
path: root/common/config_file.c
diff options
context:
space:
mode:
Diffstat (limited to 'common/config_file.c')
-rw-r--r--common/config_file.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/common/config_file.c b/common/config_file.c
index eb6da2e..aa1c289 100644
--- a/common/config_file.c
+++ b/common/config_file.c
@@ -574,7 +574,7 @@ static const char * getHome()
#include <tqdir.h>
#include <tqfile.h>
#endif
// Take from KStandardDirs::makeDir
static bool makeDir(const TQString& dir, int mode)
{
// we want an absolute path
@@ -700,7 +700,7 @@ static const char *qtcConfDir()
#if defined TQTC_TQT_ONLY || 0x039999 < 0x040000
makeDir(cfgDir, 0755);
#else
- KStandardDirs::makeDir(cfgDir, 0755);
+ TDEStandardDirs::makeDir(cfgDir, 0755);
#endif
#else
g_mkdir_with_parents(cfgDir, 0755);
@@ -574,7 +574,7 @@ static const char * getHome()
#include <tqfile.h>
#endif
-// Take from KStandardDirs::makeDir
+// Take from TDEStandardDirs::makeDir
static bool makeDir(const TQString& dir, int mode)
{